@@ -102,14 +102,22 @@ def get_currencies():
     return items
 
 
-def get_operations():
+def get_operations(account_id = None):
     path = f'/api/v1/operations'
     params = {'paging.limit': PAGE_LIMIT,
               'paging.offset': 0}
+    if account_id is not None:
+        params['filter.accountId'] = account_id
     items = pf_interaction.request_list('get', path, params=params)
     return items
 
 
+def get_account_by_id(account_id: int):
+    path = f"/api/v1/accounts/{account_id}"
+    resp, _ = pf_interaction.request('get', path)
+    return resp.json()['data']
+
+
 def get_accounts(changes_from_date=None, add_params=None):
     path = f'/api/v1/accounts'
     params = {'paging.limit': PAGE_LIMIT}
@@ -235,9 +243,46 @@ def get_user_permissions(user_id, opcat_parent_ids=None):
 
 
 def get_users():
-    path = f'/api/v1/accesscontexts'
+    path = '/api/v1/accesscontexts'
     params = {'filter.kind': 'ByBusiness',
               'paging.limit': PAGE_LIMIT}
     items = pf_interaction.request_list('get', path, params=params)
     items = [item['user'] for item in items]
     return items
+
+
+def get_account_history():
+    path = '/api/v1/bizinfos/accountshistory'
+    resp, _ = pf_interaction.request('get', path)
+    return resp.json()["data"]
+
+
+def get_balance_by_id(account_id: int):
+    account = get_account_by_id(account_id)
+    all_account_histories = get_account_history()
+    account_hist = next(ah for ah in all_account_histories if ah['accountId'] == account['accountId'])
+    fact_values = [float(fh["factValue"]) for fh in account_hist["details"]]
+    return sum(fact_values) + account["startingRemainderValue"]
+
+
+def get_balances():
+    accounts = get_accounts()
+    all_account_histories = get_account_history()
+    balances = list()
+    for account in accounts:
+        account_hist = next((ah for ah in all_account_histories if ah['accountId'] == account['accountId']), None)
+        if account_hist is None:
+            balance = 0.
+        else:
+            fact_values = [float(fh["factValue"]) for fh in account_hist["details"]]
+            if account["startingRemainderValue"] is None:
+                account["startingRemainderValue"] = 0
+            balance = sum(fact_values) + account["startingRemainderValue"]
+        balances.append({'accountId': account['accountId'],
+                         'title': account['title'],
+                         'balance': balance})
+    return balances
+
+
+
+
